/*
 *
 * File:	getConfig.c
 *
 * Function:	This file contains the routine to prompt
 * 		the user for configuration parameters used
 *		by lightcontrol software.
 *
 * Version:	1.0
 *
 * History:	Initial Release
 *
 *
 * Copyright (c) 2016 May 6 by Philip Vrbancic
 *
 * 6223 East Peabody Street
 * Long Beach, California  90808
 * United States of America
 *
 * All Rights Reserved
 *
 * This software is the confidential and proprietary
 * intellectual property of Walland Philip Vrbancic, Jr.
 *
 */


#define EXTERNAL


#include		<stdio.h>
#include		<stdlib.h>
#include		<string.h>
#include		<time.h>

#include		<sys/time.h>

#include		"standardDefs.h"
#include		"parameterDefs.h"
#include		"globalDefs.h"
#include		"protoTypes.h"



VOID
getConfig()

{
  time_t		timeT;

  STRUCT tm		*tmTime;

  STRUCT timeval	timeVal;
  STRUCT timezone	timeZone;

  CHAR			*timePtr;

  INT32			option;
  INT32			ival;

  FLT32			fval;
  FLT32			localTime;


// Enter main processing.

  for( ;; )
  {

// Clear screen and print out header and configuration.

    system( "clear" );

    time( &timeT );

    timePtr = asctime( localtime( &timeT ) );

    printf( "\nWelcome to Lightcontrol Config\n" );

    printf( "\nToday is %s\n", timePtr );

    showConfig( SCREEN );


// Get user response.

    Gets( Ans, CHAR_BUF_LEN, stdin );

    printf( "\n" );

    option = ZERO;

    if( Ans[0] == ( INT32 )NULL )
    {
      strcpy( Ans, "<cr>" );
    }

    else
    {
      sscanf( Ans, "%d", &option );
    }


// Process user response.

    if( option == 1 )
    {
      for( ;; )
      {
	printf( "\nEnter GPIO number (0-29):  " );

	Gets( Ans, CHAR_BUF_LEN, stdin );

	printf( "\n" );

	sscanf( Ans, "%d", &ival );

	if( ( ival >= ZERO ) && ( ival <= 29 ) )
	{
	  Gpio = ival;

	  break;
	}

	printf( "\nError:  '%s' is not a valid response.\n", Ans );

	Pause();
      }
    }

    else if( option == 2 )
    {
      for( ;; )
      {
	printf( "\nEnter Sunrise Offset in hours (0.0-8.0):  " );

	Gets( Ans, CHAR_BUF_LEN, stdin );

	printf( "\n" );

	sscanf( Ans, "%f", &fval );

	if( ( fval >= FZERO ) && ( fval <= 8.0 ) )
	{
	  RiseOffset = fval;

	  break;
	}

	printf( "\nError:  '%s' is not a valid response.\n", Ans );

	Pause();
      }
    }

    else if( option == 3 )
    {
      for( ;; )
      {
	printf( "\nEnter Sunset Offset in hours  (0.0-8.0):  " );

	Gets( Ans, CHAR_BUF_LEN, stdin );

	printf( "\n" );

	sscanf( Ans, "%f", &fval );

	if( ( fval >= FZERO ) && ( fval <= 8.0 ) )
	{
	  SetOffset = fval;

	  break;
	}

	printf( "\nError:  '%s' is not a valid response.\n", Ans );

	Pause();
      }
    }

    else if( option == 4 )
    {
      for( ;; )
      {
	printf( "\nEnter Timezone (-12-12):  " );

	Gets( Ans, CHAR_BUF_LEN, stdin );

	printf( "\n" );

	sscanf( Ans, "%d", &ival );

	if( ( ival >= -12 ) && ( ival <= 12 ) )
	{
	  TimeZone = ival;

	  break;
	}

	printf( "\nError:  '%s' is not a valid response.\n", Ans );

	Pause();
      }
    }

    else if( option == 5 )
    {
      for( ;; )
      {
	printf( "\nEnter Zenith in degrees (90.0-108.0):  " );

	Gets( Ans, CHAR_BUF_LEN, stdin );

	printf( "\n" );

	sscanf( Ans, "%f", &fval );

	if( ( fval >= 90.0 ) && ( fval <= 108.0 ) )
	{
	  Zenith = fval;

	  break;
	}

	printf( "\nError:  '%s' is not a valid response.\n", Ans );

	Pause();
      }
    }

    else if( option == 6 )
    {
      for( ;; )
      {
	printf( "\nEnter Latitude in degrees (-180.0 to 180.0):  " );

	Gets( Ans, CHAR_BUF_LEN, stdin );

	printf( "\n" );

	sscanf( Ans, "%f", &fval );

	if( ( fval >= -180.0 ) && ( fval <= 180.0 ) )
	{
	  Latitude = fval;

	  break;
	}

	printf( "\nError:  '%s' is not a valid response.\n", Ans );

	Pause();
      }
    }

    else if( option == 7 )
    {
      for( ;; )
      {
	printf( "\nEnter Longitude in degrees (-180.0 to 180.0):  " );

	Gets( Ans, CHAR_BUF_LEN, stdin );

	printf( "\n" );

	sscanf( Ans, "%f", &fval );

	if( ( fval >= -180.0 ) && ( fval <= 180.0 ) )
	{
	  Longitude = fval;

	  break;
	}

	printf( "\nError:  '%s' is not a valid response.\n", Ans );

	Pause();
      }
    }

    else if( option == 8 )
    {
      break;
    }

    else
    {
      printf( "\nError:  '%s' is not a valid response.\n", Ans );

      Pause();
    }
  }
}

