/*
 *
 * File:	gpioRoutines.c
 *
 * Function:	This file contains the routines to
 *		manage the GPIO ports.
 *
 * Version:	1.0
 *
 * History:	Initial Release
 *
 *
 * Copyright (c) 2016 May 6 by Philip Vrbancic
 *
 * 6223 East Peabody Street
 * Long Beach, California  90808
 * United States of America
 *
 * All Rights Reserved
 *
 * This software is the confidential and proprietary
 * intellectual property of Walland Philip Vrbancic, Jr.
 *
 */


#define EXTERNAL


#include		<stdio.h>

#include		"standardDefs.h"
#include		"parameterDefs.h"
#include		"globalDefs.h"
#include		"protoTypes.h"



INT32
openGPIO( INT32 gpio )

{
  FILE			*gpioPtr;

  CHAR			gpioPath[PATH_BUF_LEN];


  sprintf( gpioPath, "%s/export", GPIO_PATH );

  gpioPtr = fopen( gpioPath, "w+" );

  if( gpioPtr == ( FILE * )NULL )
  {
    sprintf( Mesg, "\n(openGPIO) Error from fopen() for opening file '%s'.\n\n", gpioPath );
    info( Mesg, LOGFILE );

    return( ERROR );
  }

  fprintf( gpioPtr, "%d", gpio );

  fclose( gpioPtr );

  return( OKAY );
}



INT32
closeGPIO( INT32 gpio )

{
  FILE			*gpioPtr;

  CHAR			gpioPath[PATH_BUF_LEN];


  sprintf( gpioPath, "%s/unexport", GPIO_PATH );

  gpioPtr = fopen( gpioPath, "w+" );

  if( gpioPtr == ( FILE * )NULL )
  {
    sprintf( Mesg, "\n(closeGPIO) Error from fopen() for opening file '%s'.\n\n", gpioPath );
    info( Mesg, LOGFILE );

    return( ERROR );
  }

  fprintf( gpioPtr, "%d", gpio );

  fclose( gpioPtr );

  return( OKAY );
}



INT32
ioGPIO( INT32 gpio, INT32 direction )

{
  FILE			*gpioPtr;

  CHAR			gpioPath[PATH_BUF_LEN];


  sprintf( gpioPath, "%s/gpio%d/direction", GPIO_PATH, gpio );

  gpioPtr = fopen( gpioPath, "w+" );

  if( gpioPtr == ( FILE * )NULL )
  {
    sprintf( Mesg, "\n(ioGPIO) Error from fopen() for opening file '%s'.\n\n", gpioPath );
    info( Mesg, LOGFILE );

    return( ERROR );
  }

  if( direction == 1 )
  {
    fprintf( gpioPtr, "in" );
  }

  else if( direction == 2 )
  {
    fprintf( gpioPtr, "out" );
  }

  else
  {
    sprintf( Mesg, "\n(ioGPIO) Error, direction value '%d' is wrong.\n\n", direction );
    info( Mesg, LOGFILE );

    return( ERROR );
  }

  fclose( gpioPtr );

  return( OKAY );
}



INT32
getGPIO( INT32 gpio )

{
  FILE			*gpioPtr;

  CHAR			gpioPath[PATH_BUF_LEN];
  CHAR			buffer[CHAR_BUF_LEN];

  INT32			status;
  INT32			value;


  sprintf( gpioPath, "%s/gpio%d/value", GPIO_PATH, gpio );

  gpioPtr = fopen( gpioPath, "r" );

  if( gpioPtr == ( FILE * )NULL )
  {
    sprintf( Mesg, "\n(getGPIO) Error from fopen() for opening file '%s'.\n\n", gpioPath );
    info( Mesg, LOGFILE );

    return( ERROR );
  }

  status = Gets( buffer, CHAR_BUF_LEN, gpioPtr );

  if( status == NEGONE )
  {
    sprintf( Mesg, "\n(getGPIO) Error from Gets() for reading gpioPath '%s'.\n\n", gpioPath );
    info( Mesg, LOGFILE );

    return( ERROR );
  }

  sscanf( buffer, "%d", &value );

  fclose( gpioPtr );

  return( value );
}



INT32
setGPIO( INT32 gpio, INT32 value )

{
  FILE			*gpioPtr;

  CHAR			gpioPath[PATH_BUF_LEN];


  sprintf( gpioPath, "%s/gpio%d/value", GPIO_PATH, gpio );

  gpioPtr = fopen( gpioPath, "w+" );

  if( gpioPtr == ( FILE * )NULL )
  {
    sprintf( Mesg, "\n(setGPIO) Error from fopen() for opening file '%s'.\n\n", gpioPath );
    info( Mesg, LOGFILE );

    return( ERROR );
  }

  if( value == ZERO )
  {
    fprintf( gpioPtr, "0" );
  }

  else if( value > ZERO )
  {
    fprintf( gpioPtr, "1" );
  }

  else
  {
    sprintf( Mesg, "\n(setGPIO) Error, value '%d' is wrong.\n\n", value );
    info( Mesg, LOGFILE );

    return( ERROR );
  }

  fclose( gpioPtr );

  return( OKAY );
}

