/*
 *
 * File:	lightconfig.c
 *
 * Function:	This file contains the routines to modify
 *		the configuration file for lightcontrol.
 *
 * Version:	1.0
 *
 * History:	Initial Release
 *
 *
 * Copyright (c) 2016 May 6 by Philip Vrbancic
 *
 * 6223 East Peabody Street
 * Long Beach, California  90808
 * United States of America
 *
 * All Rights Reserved
 *
 * This software is the confidential and proprietary
 * intellectual property of Walland Philip Vrbancic, Jr.
 *
 */


#undef EXTERNAL


#include			<stdio.h>
#include			<stdlib.h>
#include			<time.h>

#include			"standardDefs.h"
#include			"parameterDefs.h"
#include			"globalDefs.h"
#include			"protoTypes.h"



INT32
main( INT32 argc, CHAR *argv[] )

{
  time_t			timeT;

  CHAR				*timePtr;

  CHAR				logPath[PATH_BUF_LEN];

  INT32				status;


// Create the log file and write the current date and time.

  sprintf( logPath, "%s/%s.log", LIGHTCONTROL_PATH, LOG_FILE_CONFIG );

  LogFilePtr = fopen( logPath, "w" );

  if( LogFilePtr == ( FILE * )NULL )
  {
    exit( EXIT_FAILURE );
  }

  time( &timeT );

  timePtr = asctime( localtime( &timeT ) );

  sprintf( Mesg, "This Log File is %s.log, at %s\n", LOG_FILE_CONFIG, timePtr );
  info( Mesg, LOGFILE );


// Get the configuration variables.

  info( "(lightconfig) Calling readConfig().\n", LOGFILE );

  status = readConfig();

  if( status )
  {
    info( "\n(lightconfig) Error from readConfig().\n", LOGFILE );

    fclose( LogFilePtr );

    exit( EXIT_FAILURE );
  }


// Show the configuration into the logfile.

  info( "(lightconfig) Calling showConfig().\n", LOGFILE );

  showConfig( LOGFILE );


// Get the new configuration variables.

  info( "(lightconfig) Calling getConfig().\n", LOGFILE );

  getConfig();


// Show the configuration into the logfile.

  info( "(lightconfig) Calling showConfig().\n", LOGFILE );

  showConfig( LOGFILE );


// Save the configuration variables.

  info( "(lightconfig) Calling saveConfig().\n", LOGFILE );

  status = saveConfig();

  if( status )
  {
    info( "\n(lightconfig) Error from saveConfig().\n", LOGFILE );

    fclose( LogFilePtr );

    exit( EXIT_FAILURE );
  }


// Exit program.

  info( "(lightconfig) Program exiting.\n\n", LOGFILE );

  fclose( LogFilePtr );
}

