/*
 *
 * File:	readConfig.c
 *
 * Function:	This file contains the routine to read
 *		the lightcontrol configuration file.
 *
 * Version:	1.0
 *
 * History:	Initial Release
 *
 *
 * Copyright (c) 2016 May 6 by Philip Vrbancic
 *
 * 6223 East Peabody Street
 * Long Beach, California  90808
 * United States of America
 *
 * All Rights Reserved
 *
 * This software is the confidential and proprietary
 * intellectual property of Walland Philip Vrbancic, Jr.
 *
 */


#define EXTERNAL


#include		<stdio.h>
#include		<string.h>

#include		"standardDefs.h"
#include		"parameterDefs.h"
#include		"globalDefs.h"
#include		"protoTypes.h"



INT32
readConfig()

{
  FILE			*fd;

  CHAR			configPath[PATH_BUF_LEN];
  CHAR			tag[CHAR_BUF_LEN];

  INT32			status;


  sprintf( configPath, "%s/%s.cfg", LIGHTCONTROL_PATH, CONFIG_FILE );

  fd = fopen( configPath, "r" );

  if( fd == ( FILE * )NULL )
  {
    sprintf( Mesg, "\n(readConfig) Error from fopen() for reading configuration file '%s'.\n", configPath );
    info( Mesg, LOGFILE );

    Pause();

    return( ERROR );
  }


// Initialize global variables;

  Gpio = ZERO;

  RiseOffset = FZERO;
  SetOffset  = FZERO;

  TimeZone = ZERO;

  Latitude  = FZERO;
  Longitude = FZERO;


// Read the configuration file variables.

  for( ;; )
  {
    status = readConfigLine( Cdata, CHAR_BUF_LEN, fd );

    if( status == NEGONE ) break;

    sscanf( Cdata, "%s", tag );


    // printf( "(readConfig) tag = %s\n", tag );


    if( strcmp( tag, "gpio:" ) == MATCH )
    {
      sscanf( Cdata, "%s %d", tag, &Gpio );
    }


    else if( strcmp( tag, "riseOffset:" ) == MATCH )
    {
      sscanf( Cdata, "%s %f", tag, &RiseOffset );
    }


    else if( strcmp( tag, "setOffset:" ) == MATCH )
    {
      sscanf( Cdata, "%s %f", tag, &SetOffset );
    }


    else if( strcmp( tag, "timeZone:" ) == MATCH )
    {
      sscanf( Cdata, "%s %d", tag, &TimeZone );
    }


    else if( strcmp( tag, "zenith:" ) == MATCH )
    {
      sscanf( Cdata, "%s %f", tag, &Zenith );
    }


    else if( strcmp( tag, "latitude:" ) == MATCH )
    {
      sscanf( Cdata, "%s %f", tag, &Latitude );
    }


    else if( strcmp( tag, "longitude:" ) == MATCH )
    {
      sscanf( Cdata, "%s %f", tag, &Longitude );
    }
  }


  fclose( fd );

  return( OKAY );
}

